package com.steering.pss.sale.order.qualityDesign.Dao.imp;

import java.sql.Connection;
import java.sql.SQLException;

import com.steering.pss.sale.order.model.DesignMscBiltCEntity;
import com.steering.pss.sale.order.model.DesignMscBiltCPlEntity;
import com.steering.pss.sale.order.model.DesignMscBiltEntity;
import com.steering.pss.sale.order.model.DesignMscBiltPlEntity;
import com.steering.pss.sale.order.model.DesignMscGzGgEntity;
import com.steering.pss.sale.order.model.DesignMscGzGgPlEntity;
import com.steering.pss.sale.order.model.DesignMscPlEntity;
import com.steering.pss.sale.order.model.DesignMscPlGxPrlEntity;
import com.steering.pss.sale.order.model.DesignMscPlGzEntity;

public interface StandardDaoImp {
	/**
	 * 验证钢种
	 * 
	 * @param con
	 * @param gradeInfo
	 * @return
	 * @throws SQLException
	 */
	int checkDesignGrade(Connection con, DesignMscPlGzEntity gradeInfo)
			throws SQLException;

	/**
	 * 验证轧管规格
	 * 
	 * @param con
	 * @param rollSpecs
	 * @return
	 * @throws SQLException
	 */
	int checkRollSpec(Connection con, DesignMscGzGgEntity rollSpecs)
			throws SQLException;

	/**
	 * 验证锻造规格
	 * 
	 * @param con
	 * @param billSpec
	 * @return
	 * @throws SQLException
	 */
	int checkBillSpec(Connection con, DesignMscBiltEntity billSpec)
			throws SQLException;

	/**
	 * 验证铸造规格
	 * 
	 * @param con
	 * @param billCSpec
	 * @return
	 * @throws SQLException
	 */
	int checkBillCSpec(Connection con, DesignMscBiltCEntity billCSpec)
			throws SQLException;

	/**
	 * 验证制程产线
	 * 
	 * @param con
	 * @param zcLine
	 * @return
	 * @throws SQLException
	 */
	int checkZCline(Connection con, DesignMscPlGxPrlEntity zcLine)
			throws SQLException;

	/**
	 * 验证轧管产线
	 * 
	 * @param con
	 * @param rollLine
	 * @return
	 * @throws SQLException
	 */
	int checkRollLine(Connection con, DesignMscGzGgPlEntity rollLine)
			throws SQLException;

	/**
	 * 验证锻造产线
	 * 
	 * @param con
	 * @param billLine
	 * @return
	 * @throws SQLException
	 */
	int checkBillLine(Connection con, DesignMscBiltPlEntity billLine)
			throws SQLException;

	/**
	 * 验证铸造产线
	 * 
	 * @param con
	 * @param billLine
	 * @return
	 * @throws SQLException
	 */
	int checkBillCLine(Connection con, DesignMscBiltCPlEntity billLine)
			throws SQLException;

	/**
	 * 验证制程
	 * 
	 * @param con
	 * @param proDuc
	 * @return
	 * @throws SQLException
	 */
	int checkProduc(Connection con, DesignMscPlEntity proDuc)
			throws SQLException;
}
